/**
 * Svelte action to activate validation framework for the form.
 * @module data/use-form-validation
 */
import type { FormController, RuleDefinition } from "../data/common";
import type { FormSettings, JQueryApi } from "../data/semantic-types";
export type FormApi = {
    form(settings?: FormSettings): void;
    form(command: string, arg1?: unknown, arg2?: unknown): unknown;
};
/**
 * Form validation controller. Is accessed by both `<FormValidation>` and individual `<InitField>`.
 * */
export declare class SuiFormController implements FormController {
    formId: string;
    elem: JQueryApi & FormApi;
    isActive: boolean;
    rules: Record<string, RuleDefinition>;
    validCallback: (valid: boolean) => void;
    errorsCallback: (errors: string[]) => void;
    constructor(elem: JQueryApi, validCallback: (valid: boolean) => void, errorsCallback: (errors: string[]) => void);
    private activateRule;
    private deactivateRule;
    addRule(key: string, rule: RuleDefinition): void;
    removeRule(key: string, rule: RuleDefinition): void;
    setActive(newValue: boolean): void;
    doValidateField(key: string): void;
    doValidateForm(): void;
    onFieldChange(key: string): void;
}
