/**
 * Svelte action to activate validation framework for the form.
 * @module data/use-form-validation
 */
import { uid } from "../data/common";
function ruleToStr(rule) {
    const isObject = Array.isArray(rule) || typeof rule === "object";
    return isObject ? JSON.stringify(rule) : String(rule);
}
/**
 * Form validation controller. Is accessed by both `<FormValidation>` and individual `<InitField>`.
 * */
// function getFieldByKey(key: string): JQueryApi {
//     let field = elem.find(`#${key}`);
//     if (field.length > 0) {
//         return field;
//     }
//     field = elem.find(`[name=${key}]`);
//     if (field.length > 0) {
//         return field;
//     }
//     field = elem.find(`[data-validate=${key}]`);
//     if (field.length > 0) {
//         return field;
//     }
//     throw new Error(`Field not found for key=${key}`);
// }
// function getFieldPrompt(key: string): string {
//     const field = getFieldByKey(key);
//     const prompt = field.parent().find(".prompt");
//     if (prompt.length > 0) {
//         return prompt.text();
//     } else {
//         return "";
//     }
// }
export class SuiFormController {
    constructor(elem, validCallback, errorsCallback) {
        // errMsg: JQueryApi;
        this.isActive = false;
        this.rules = {};
        this.elem = elem;
        this.formId = `FORM_${elem.attr("id") ?? uid()}`;
        // this.errMsg = elem.find(".ui.message.error");
        // if (this.errMsg.length === 0) {
        //     throw new Error("Semantic form is not initialized");
        // }
        this.validCallback = validCallback;
        this.errorsCallback = errorsCallback;
    }
    activateRule(key, rule) {
        console.log(`${this.formId} : add_rule - ${key} : ${ruleToStr(rule)}`);
        this.elem.form("add rule", key, rule);
    }
    deactivateRule(key, rule) {
        console.log(`${this.formId} : remove_rule - ${key} : ${ruleToStr(rule)}`);
        // must use 'remove field', not 'remove rule' if all the rules are removed
        this.elem.form("remove field", key);
    }
    addRule(key, rule) {
        this.rules[key] = rule;
        if (this.isActive) {
            this.activateRule(key, rule);
        }
    }
    removeRule(key, rule) {
        delete this.rules[key];
        if (this.isActive) {
            this.deactivateRule(key, rule);
        }
    }
    setActive(newValue) {
        console.debug(`${this.formId} : active -> ${newValue}`);
        // eslint-disable-next-line eqeqeq
        if (this.isActive == false && newValue == true) {
            // start validating
            Object.keys(this.rules).forEach((key) => {
                this.activateRule(key, this.rules[key]);
            });
            this.isActive = true;
            setTimeout(() => {
                this.doValidateForm();
            }, 0);
        }
        // eslint-disable-next-line eqeqeq
        if (this.isActive == true && newValue == false) {
            Object.keys(this.rules).forEach((key) => {
                this.deactivateRule(key, this.rules[key]);
            });
            // remove validation highlights
            this.elem.find(".field.error").removeClass("error");
            this.elem.find(".message.error").html("");
            this.elem.find(".prompt").remove();
            this.isActive = false;
        }
    }
    // private checkIfValid(): void {
    //     console.debug("CHECK IF VALID");
    //     // update 'valid' binding
    //     const res: boolean = this.elem.form("is valid");
    //     // this.validCallback(res);
    //     // // get errors from message and update 'errors' binding
    //     // if (this.errMsg.length) {
    //     //     // const newErrors: string[] = [];
    //     //     // msg.find("ul li").each((_idx: number, item: Element) => {
    //     //     //     newErrors.push(jQueryElem(item).text());
    //     //     // });
    //     //     const newErrors: string[] = this.errMsg
    //     //         .find("ul li")
    //     //         .map((_ind: number, el: Element) => jQueryElem(el).text())
    //     //         .get();
    //     //     console.debug("NEW ERRORS", this.errMsg, newErrors);
    //     //     this.errorsCallback(newErrors);
    //     // }
    // }
    doValidateField(key) {
        this.elem.form("validate field", key);
        // this.checkIfValid();
        this.elem.form("is valid");
    }
    doValidateForm() {
        this.elem.form("validate form");
        // this.checkIfValid();
        this.elem.form("is valid");
    }
    onFieldChange(key) {
        if (this.isActive) {
            console.log(`${this.formId} : revalidate (${key})`);
            this.doValidateForm();
            // doValidateField(key) can't be used, as it doesn't cause onSuccess / on Failure event
        }
    }
}
