/**
 * 'fmt' and 'parse' utility object, input formatter classes.
 * @module data/input-formatter
 */
import type { DataTypes, DateFormatter, ListFormatter, NumberFormatter, TextFormatter } from "../data/common";
import type { CalendarSettings, DateFormatFn, NumberSettings, NumberInputSettings } from "../data/semantic-types";
export declare class NumberFmt implements NumberFormatter {
    type: "integer" | "decimal" | "money";
    precision: number;
    settings: NumberSettings;
    prefixRegex: RegExp | undefined;
    suffixRegex: RegExp | undefined;
    constructor(inputSettings: NumberInputSettings);
    parse(value: string): number | undefined;
    format(val: number | undefined): string;
}
/** How to upper-case the text */
export type TextFormatSettings = {
    case?: "upper" | "lower" | "title" | "none";
    char?: "ascii" | "id" | "id-under" | "id-dash" | "notags" | "no-squote" | "no-dquote";
};
export declare class TextFmt implements TextFormatter {
    caseMode: TextFormatSettings["case"];
    constructor(settings?: TextFormatSettings);
    format(val: DataTypes): string;
}
export declare class ListFmt implements ListFormatter {
    separator: string;
    constructor(sep?: string);
    parse(val: string): string[];
    format(val: DataTypes): string;
}
export declare class DateFmt implements DateFormatter {
    private settings;
    constructor(settings?: CalendarSettings);
    protected weekOfYear(weekYear: number, weekMonth: number, weekDay: number): number;
    protected helperDateFormat(format: string | DateFormatFn, date: Date, sett?: CalendarSettings): string;
    parse(val: string): Date | undefined;
    format(val: DataTypes): string;
}
