/**
 * Common types, jQuery API, Form and Data controllers, utility functions.
 * @module data/settings
 */
import type { CalendarSettings, CheckboxSettings, DropdownSettings, FormSettings, ModalSettings, NumberSettings, PopupSettings, SliderSettings, StickySettings, ToastSettings } from "./semantic-types";
export type SettingsObject = {
    [key: string]: unknown;
};
export type AllSettingsJson = {
    [key: string]: SettingsObject;
};
/** Provides acces to Sematic UI settings for different components. */
export declare class SettingsHelper<T> {
    compName: string;
    constructor(compName: string);
    /** Returns settings object. */
    read(): Required<T>;
    /** Copy settings into the global SUI components in jQuery. */
    apply(val: T): void;
}
/** Copy settings into the global SUI components and number object in jQuery. */
export declare function applyAllSettings(json: AllSettingsJson): void;
export declare const calendarDefaults: SettingsHelper<CalendarSettings>;
export declare const checkboxDefaults: SettingsHelper<CheckboxSettings>;
export declare const dropdownDefaults: SettingsHelper<DropdownSettings>;
export declare const formDefaults: SettingsHelper<FormSettings>;
export declare const modalDefaults: SettingsHelper<ModalSettings>;
export declare const numberDefaults: SettingsHelper<NumberSettings>;
export declare const popupDefaults: SettingsHelper<PopupSettings>;
export declare const sliderDefaults: SettingsHelper<SliderSettings>;
export declare const stickyDefaults: SettingsHelper<StickySettings>;
export declare const toastDefaults: SettingsHelper<ToastSettings>;
/** Must be called after DOM is initailized. Like in sveltekit rotes/layout.ts load(). */
export declare function applyDefaultSettings(locale?: string): void;
