/**
 * Internatinalization module.
 * Dynamically import translations and formats based on locale.
 * See routes/i18n/extra-locales.ts for an example how to extend it.

```text
locale      money           date time   week
--------------------------------------------
de-DE   €1.000,00     01.03.2024 14:50     1
en-CA   $1 000.00     2024-03-01 14:50     0
en-GB   £1,000.00     01/03/2024 14:50     1
en-US   $1,000.00       3/1/2024 2:50 PM   0
es-ES    1.234,56 €    1-03-2024 14.50     1
es-MX   $1,000.00      1/03/2024 14:50     0
es-US   $1,000.00       3/1/2024 2:50 PM   0
fr-CA    1 000,00 $   2024-03-01 14:50     1
fr-FR    1 000,00 €   01/03/2024 14:50     1
```

Sources:
- https://docs.oracle.com/cd/E19455-01/806-0169/overview-9/index.html
- https://en.wikipedia.org/wiki/List_of_date_formats_by_country
- https://gist.github.com/mlconnor/1887156
- https://en.wikipedia.org/wiki/Decimal_separator
- https://leap.hcldoc.com/help/topic/SSS28S_8.2.1/XFDL_Specification/i_xfdl_r_formats_en_CA.html
 * @module i18n
 */
/** Register translation loading function. */
export declare function registerLanguage(language: string, fn: () => Promise<object>): void;
/** Returns list of supported languages. */
export declare function supportedLanguages(): string[];
/** Register locale loading function. */
export declare function registerLocale(locale: string, fn: () => Promise<object>): void;
/** Returns list of supported locales. */
export declare function supportedLocales(): string[];
/** Return currently set locale. */
export declare function getLocale(): string;
/** Imports locale settings: validation messages, calendar, date and number formats.
    Returns applied local string or null if locale is not found */
export declare function applyLocale(locale: string): Promise<string | null>;
/** Register known locales.
 * Only required translations and settings are dynamically loaded into memory
 * when {@link i18n.applyLocale} is called.
 * */
export declare function registerBaseLocales(): void;
